#!/usr/bin/perl
use strict ;
use warnings ;
use autodie ;

use Test::More tests => 14 ;

use Devel::Cover ;

use Stanford::Orange::Util
  qw/
    run_command
    run_command_improved
    trim
    / ;

my ($stdout, $stderr, $exit_value, $cmd, @cmd) ;

## TEST A1.
$cmd = 'ls /' ;
($stdout, $stderr, $exit_value) = run_command($cmd) ;

ok ($exit_value == 0) ;
ok ($stdout =~ m{bin}xsm) ;
ok ($stdout =~ m{dev}xsm) ;
ok ($stdout =~ m{etc}xsm) ;

## TEST A2.
@cmd = qw(ls /) ;
($stdout, $stderr, $exit_value) = run_command_improved(@cmd) ;

ok ($exit_value == 0) ;
ok ($stdout =~ m{bin}xsm) ;
ok ($stdout =~ m{dev}xsm) ;
ok ($stdout =~ m{etc}xsm) ;

## TEST B1.
# Let's do something that generates an error.
$cmd ='ls /bogus' ;
($stdout, $stderr, $exit_value) = run_command($cmd) ;
ok ($exit_value == 2) ;
ok (trim($stdout) eq q{}) ;

## no critic (ProhibitComplexRegexes)
ok (trim($stderr) =~ m{cannot[ ]access[ ].*\/bogus.*:[ ]No[ ]such[ ]file[ ]or[ ]directory}xsm,
    'listing non-existent directory generates correct stderr') ;

## TEST B2.
@cmd = qw(/usr/bin/ls /bogus) ;
($stdout, $stderr, $exit_value) = run_command($cmd) ;
ok ($exit_value == 2, 'listing non-exsitent directory has exit code 2') ;
ok (trim($stdout) eq q{}) ;

## no critic (ProhibitComplexRegexes)
ok (trim($stderr) =~ m{cannot[ ]access[ ].*\/bogus.*:[ ]No[ ]such[ ]file[ ]or[ ]directory}xsm) ;

