#!/usr/bin/perl
use strict ;
use warnings ;
use autodie ;

use Test::More tests => 9;

use Stanford::Orange::Util
  qw/
    slurp
    / ;

my $x ;

# Test slurp
$x = slurp('./t/slurp_test.txt') ;
ok ($x eq "Hello, world.\n\nThis is a sentence.") ;

# Slurp this file with a high limit.
$x = slurp('./t/slurp_test.txt', 34) ;
ok ($x eq "Hello, world.\n\nThis is a sentence.") ;

# Slurp this file with a low limit.
eval
{
  $x = slurp('./t/slurp_test.txt', 33) ;
} ;

ok ($@ =~ m{\d+[ ]bytes[ ]exceeding[ ]the[ ]limit[ ]of[ ]\d+}xsm) ;

# Slurp this file with a 0 limit (limit should be ignored)
$x = slurp('./t/slurp_test.txt', 0) ;
ok ($x eq "Hello, world.\n\nThis is a sentence.") ;

# Slurp this file with a negative limit (limit should be ignored)
$x = slurp('./t/slurp_test.txt', -10) ;
ok ($x eq "Hello, world.\n\nThis is a sentence.") ;

# Slurp an empty file.
$x = slurp('./t/empty.txt') ;
ok ($x eq q{}) ;

$x = slurp('./t/empty.txt', 1) ;
ok ($x eq q{}) ;

# Slurp a non-existent file
eval
{
  $x = slurp('./t/does_not_exist.txt') ;
} ;
ok ($@ =~ m{can.t[ ]open[ ].*[ ]for[ ]slurping}ixsm) ;

# Slurp a non-existent file (with size limit)
eval
{
  $x = slurp('./t/does_not_exist.txt', 10) ;
} ;
ok ($@ =~ m{can.t[ ]open[ ].*[ ]for[ ]slurping}xsm) ;
